﻿' EXAMPLE - SQL02 for Visual Basic using ADO.NET
' When you run this example, a new database is created with two tables
' where one references the other.  Then a single row is created in the
' referenced table and four rows are created in the referencing table.
' Finally all the data is read from the database using a join.
' 
' The following methods are illustrated:
'     Raima.Rdm.RdmConnection:
'         Close() Method
'         CreateCommand() Method
'         Open() Method
'         RdmConnection() Constructor
'     Raima.Rdm.RdmCommand:
'         CommandText Property
'         ExecuteNonQuery() Method
'         ExecuteReader() Method
'     Raima.Rdm.RdmDataReader:
'         Item[int] Property
'         Read() Method
' 
' They are fully document in http://docs.raima.com/rdm/.
' 
' For simplicity this example does not catch any thrown execptions
' but good programming practices would dictate that this occur in
' a full application.

' Raima.Rdm is the system module that contains the ADO.NET
' data provider for RDM
Imports Rdm = Raima.Rdm

Module SQL02

    Sub CreateDatabase()
        ' Attempt to create the database.  If the database already
        ' exists this will fail and we simply ignore the failure
        ' for this sample.
        Dim conn As Rdm.RdmConnection
        conn = New Rdm.RdmConnection("host=local")
        conn.Open()

        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        Try
            Dim dropCmds(0 To 1) As String
            dropCmds(0) = "DROP DATABASE SQL02"
            dropCmds(1) = "COMMIT"

            For Each c In dropCmds
                cmd.CommandText = c
                cmd.ExecuteNonQuery()
            Next

        Catch ex As Exception
        End Try

        Dim createCmds(0 To 3) As String

        createCmds(0) = "CREATE DATABASE SQL02"
        createCmds(1) = "CREATE TABLE PriTab (pid INTEGER PRIMARY KEY, pstr CHAR(30))"
        createCmds(2) = "CREATE TABLE ForTab (fstr CHAR(30), pid INTEGER REFERENCES PriTab(pid))"
        createCmds(3) = "COMMIT"

        For Each c In createCmds
            cmd.CommandText = c
            cmd.ExecuteNonQuery()
        Next

        conn.Close()
    End Sub

    Sub Main()
        CreateDatabase()

        ' Create the connection with a simple connection string
        Dim conn As Rdm.RdmConnection
        conn = New Rdm.RdmConnection("host=local;database=SQL02;openmode=x")

        ' Open the connection to the database
        conn.Open()

        ' Create a new command
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        ' Insert a row into the referenced table
        cmd.CommandText = "INSERT INTO PriTab VALUES 1, 'referenced 1'"
        cmd.ExecuteNonQuery()

        ' Insert four rows into the referencing table
        For ii = 1 To 4
            cmd.CommandText = "INSERT INTO ForTab VALUES 'referencing " + Convert.ToString(ii) + "', 1"
            cmd.ExecuteNonQuery()
        Next

        ' Scan through all the existing rows using a join and print out the
        ' contents
        cmd.CommandText = "SELECT pstr, fstr FROM ForTab, PriTab where ForTab.pid = PriTab.pid"
        Dim reader As Rdm.RdmDataReader
        reader = cmd.ExecuteReader()

        While (reader.Read())
            Console.WriteLine(reader.Item(0) + " -- " + reader.Item(1))
        End While

        conn.Close()

        Console.WriteLine("Hit <Enter> to continue")
        Console.ReadLine()
    End Sub
End Module
